"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.builder = exports.desc = exports.command = void 0;
const component_1 = require("../component");
const core_1 = require("../core");
const workspace_1 = require("../workspace");
exports.command = 'stop [services..]';
exports.desc = 'Stop one or more services.';
const builder = yargs => (0, core_1.yargsAddGlobalOptions)(yargs).options({
    services: {
        array: true,
        type: 'string',
        demandOption: true,
    },
    force: {
        type: 'boolean',
    },
});
exports.builder = builder;
const handler = async (args) => {
    const cwd = process.cwd().replace(/\\/g, '/');
    // TODO: store workspace name in ~/home/.uniform/settings.json
    const wsPath = cwd;
    const ws = (0, workspace_1.createWorkspace)(wsPath, cwd);
    await (0, workspace_1.loadWorkspace)(ws);
    await (0, workspace_1.initWorkspace)(ws);
    const options = {
        debug: args.debug,
        force: args.force,
        dryRun: args.dryRun,
    };
    for (const compName of args.services) {
        const comp = ws.components.get(compName);
        if (!comp)
            throw new Error('service ' + compName + ' not found');
        await (0, component_1.componentStop)(comp, options);
    }
};
exports.handler = handler;
